#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hie-compat
version:              0.2.0.0
visibility:           public
id:                   hie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
key:                  hie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
license:              Apache-2.0
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             HIE files for GHC 8.6 and other HIE file backports
description:
    Backports for HIE files to GHC 8.6, along with a few other backports
    of HIE file related fixes for ghcide.
    THIS DOES NOT LET YOU READ HIE FILES WITH MISMATCHED VERSIONS OF GHC

category:             Development
abi:                  c487c1999604167d50c1eec0ae78e2bc
exposed:              True
exposed-modules:
    Compat.HieAst Compat.HieBin Compat.HieDebug Compat.HieTypes
    Compat.HieUtils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hie-compat-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hie-compat-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hie-compat-0.2.0.0
hs-libraries:         HShie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    directory-1.3.6.0 filepath-1.4.2.1 ghc-8.10.5 ghc-boot-8.10.5
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hie-compat/html/hie-compat.haddock
haddock-html:         /usr/share/doc/haskell-hie-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

